@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.aws_s3._jsii
@@ -16,9 +16,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-lambda-s3",
-    "1.56.0",
+    "1.62.0",
     __name__[0:-6],
-    "aws-lambda-s3@1.56.0.jsii.tgz",
+    "aws-lambda-s3@1.62.0.jsii.tgz",
 )
 
 __all__ = [
